@@ -7,6 +7,7 @@
 #import "MyFileTab.h"
 #import "NJBTransactionResult.h"
 #import "MyTableTab.h"
+#import "MyNSArrayController.h"
 
 @interface MusicTab : MyFileTab
 {
@@ -15,6 +16,11 @@
 	NSDictionary *fileExtensionsToCodecsDictionary;
 	activeObjects objectToSaveTrack;
 	BOOL trackListUpToDate;
+	IBOutlet MyNSArrayController *iTunesArrayController;
+	IBOutlet NSTextField *iTunesSearchField;
+	IBOutlet NSTextField *iTunesItemCountField;
+  IBOutlet NSTableView *iTunesTable;
+	IBOutlet NSBox *iTunesBox;
 }
 - (void)loadTracks;
 - (NJBTransactionResult *)downloadTrackList;
@@ -23,5 +29,8 @@
 - (void)replaceTrack:(Track *)replace withTrack:(Track *)new;
 - (void)writeTagToFile:(Track *)track;
 - (NJBTransactionResult *)uploadTrack:(Track *)track;
+- (void)addTrackToiTunes:(Track *)track;
+- (IBAction)searchiTunesTableAction:(id)sender;
+- (void)setCorrectView;
 
 @end
