@@ -246,6 +246,16 @@
 	[defaults setObject:downloadDir forKey:PREF_KEY_DOWNLOAD_DIR];
 }
 
+- (NSString *)iTunesMusicLibraryLocation
+{
+	return [defaults objectForKey:PREF_KEY_ITUNES_LOCATION];
+}
+
+- (void)setiTunesMusicLibraryLocation:(NSString *)iTunesMusicLibraryLocation
+{
+	[defaults setObject:iTunesMusicLibraryLocation forKey:PREF_KEY_ITUNES_LOCATION];
+}
+
 /**********************/
 
 - (void)registerDefaults
@@ -292,6 +302,8 @@
 	[defaultValues setObject:DEFAULT_PREF_KEY_ITUNES_INTEGRATION forKey:PREF_KEY_ITUNES_INTEGRATION];
 	// DOWNLOAD_DIR
 	[defaultValues setObject:DEFAULT_PREF_KEY_DOWNLOAD_DIR forKey:PREF_KEY_DOWNLOAD_DIR];
+	// ITUNES_LOCATION
+	[defaultValues setObject:DEFAULT_PREF_KEY_ITUNES_LOCATION forKey:PREF_KEY_ITUNES_LOCATION];
 	
 	[defaults registerDefaults:defaultValues];
 }
