@@ -117,17 +117,20 @@
 	if (![preferences iTunesIntegration])
 	{
 		[downloadedTrackDir setEnabled:NO];
+		[iTunesMusicLibraryLocation setEnabled:NO];
 	}
 	else
 	{
 		[downloadedTrackDir setEnabled:YES];
-		[downloadedTrackDir setStringValue:[preferences downloadDir]];
+		[iTunesMusicLibraryLocation setEnabled:YES];
 	}
+	// show these anyway
+	[downloadedTrackDir setStringValue:[preferences downloadDir]];
+	[iTunesMusicLibraryLocation setStringValue:[preferences iTunesMusicLibraryLocation]];
 	
 	// start with no changes
 	// this goes at the end as setting text above causes boxes to call controlTextDidChange
 	isDirty = NO;
-	
 }
 
 /* Sets the button state mapping YES->NSOnState, NO->NSOffState
@@ -199,6 +202,7 @@
 	{
 		[preferences setiTunesIntegration:YES];
 		[preferences setDownloadDir:[downloadedTrackDir stringValue]];
+		[preferences setiTunesMusicLibraryLocation:[iTunesMusicLibraryLocation stringValue]];
 	}
 	else
 	{
@@ -394,10 +398,12 @@
 	if ([iTunesIntegration state] == NSOnState)
 	{	
 		[downloadedTrackDir setEnabled:YES];
+		[iTunesMusicLibraryLocation setEnabled:YES];
 	}
 	else
 	{
 		[downloadedTrackDir setEnabled:NO];
+		[iTunesMusicLibraryLocation setEnabled:NO];
 	}
 	isDirty = YES;
 }
