@@ -341,6 +341,7 @@ ptp_read_func (unsigned char *bytes, unsigned int size, void *data, unsigned int
   int toread = 0;
   int result = 0;
   int curread = 0;
+	int i = 0;
   /* Split into small blocks. Too large blocks (>1x MB) would
    * timeout.
    */
@@ -668,20 +669,17 @@ next_step:
   }
   
   ret = ptp_opensession(params,1);
-  // printf("Session open (%d)...\n", ret);
   if (ret == PTP_RC_InvalidTransactionID) {
     params->transaction_id += 10;
     ret = ptp_opensession(params,1);
   }
   if (ret != PTP_RC_SessionAlreadyOpened && ret != PTP_RC_OK) {
-    printf("Could not open session! (Return code %d)\n  Try to reset the device.\n", ret);
     usb_release_interface(ptp_usb->handle,dev->config->interface->altsetting->bInterfaceNumber);
   }
 
   // It is actually permissible to call this before opening the session
   ret = ptp_getdeviceinfo(params, &deviceinfo);
   if (ret != PTP_RC_OK) {
-    printf("Could not get device info!\n");
     usb_release_interface(ptp_usb->handle,dev->config->interface->altsetting->bInterfaceNumber);
     return PTP_CD_RC_ERROR_CONNECTING;
   }
